@@ -15,11 +15,15 @@ from . import (
 )
 from .cross_validation import batch_cross_validation
 from .fit import fit_gpytorch_model
-from .gen import gen_candidates_scipy, gen_candidates_torch, get_best_candidates
+from .generation.gen import (
+    gen_candidates_scipy,
+    gen_candidates_torch,
+    get_best_candidates,
+)
 from .utils import manual_seed
 
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 __all__ = [
