@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
-
-# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
+# Copyright (c) Facebook, Inc. and its affiliates.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
 
 r"""
 Objective Modules to be used with acquisition functions.
 """
 
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
 from typing import Callable, List
 
@@ -144,7 +148,7 @@ class LinearMCObjective(MCAcquisitionObjective):
         """
         if samples.shape[-1] != self.weights.shape[-1]:
             raise RuntimeError("Output shape of samples not equal to that of weights")
-        return torch.einsum("...o, o", [samples, self.weights])
+        return torch.einsum("...m, m", [samples, self.weights])
 
 
 class GenericMCObjective(MCAcquisitionObjective):
