@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
-
-# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
+# Copyright (c) Facebook, Inc. and its affiliates.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
 
 r"""
 Cross-validation utilities using batch evaluation mode.
 """
 
+from __future__ import annotations
+
 from typing import Any, Dict, NamedTuple, Optional, Type
 
 import torch
