@@ -1,6 +1,8 @@
 #!/usr/bin/env python3
-
-# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
+# Copyright (c) Facebook, Inc. and its affiliates.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
 
 from .errors import (
     BotorchError,
@@ -13,6 +15,7 @@ from .warnings import (
     BadInitialCandidatesWarning,
     BotorchTensorDimensionWarning,
     BotorchWarning,
+    CostAwareWarning,
     InputDataWarning,
     OptimizationWarning,
     SamplingWarning,
@@ -25,6 +28,7 @@ __all__ = [
     "BotorchTensorDimensionError",
     "BotorchTensorDimensionWarning",
     "BotorchWarning",
+    "CostAwareWarning",
     "InputDataWarning",
     "InputDataError",
     "BadInitialCandidatesWarning",
