@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
-
-# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
+# Copyright (c) Facebook, Inc. and its affiliates.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
 
 r"""
 Utilities for model fitting.
 """
 
+from __future__ import annotations
+
 import logging
 import warnings
 from copy import deepcopy
@@ -44,7 +48,8 @@ def fit_gpytorch_model(
         optimizer: The optimizer function.
         kwargs: Arguments passed along to the optimizer function, including
             `max_retries` and `sequential` (controls the fitting of `ModelListGP`
-            and `BatchedMultiOutputGPyTorchModel` models).
+            and `BatchedMultiOutputGPyTorchModel` models) or `approx_mll`
+            (whether to use gpytorch's approximate MLL computation).
 
     Returns:
         MarginalLogLikelihood with optimized parameters.
@@ -81,7 +86,8 @@ def fit_gpytorch_model(
             model_ = model_list_to_batched(mll_.model)
             mll.model.load_state_dict(model_.state_dict())
             return mll.eval()
-        except (NotImplementedError, UnsupportedError, RuntimeError, AttributeError):
+        # NotImplentedError is omitted since it derives from RuntimeError
+        except (UnsupportedError, RuntimeError, AttributeError):
             warnings.warn(FAILED_CONVERSION_MSG, BotorchWarning)
             return fit_gpytorch_model(
                 mll=mll, optimizer=optimizer, sequential=False, max_retries=max_retries
