@@ -1,4 +1,4 @@
-#! /usr/bin/env python3
+#!/usr/bin/env python3
 # Copyright (c) Facebook, Inc. and its affiliates.
 #
 # This source code is licensed under the MIT license found in the
@@ -408,10 +408,10 @@ class BatchedMultiOutputGPyTorchModel(GPyTorchModel):
             )
 
         m = len(idcs)
-        tidxr = torch.tensor(idcs)
+        new_model = deepcopy(self)
+        tidxr = torch.tensor(idcs, device=new_model.train_targets.device)
         idxr = tidxr if m > 1 else idcs[0]
         new_tail_bs = torch.Size([m]) if m > 1 else torch.Size()
-        new_model = deepcopy(self)
 
         new_model._num_outputs = m
         new_model._aug_batch_shape = new_model._aug_batch_shape[:-1] + new_tail_bs
@@ -426,7 +426,7 @@ class BatchedMultiOutputGPyTorchModel(GPyTorchModel):
         ):
             if full_name in subset_batch_dict:
                 idx = subset_batch_dict[full_name]
-                new_data = p.index_select(idx, tidxr)
+                new_data = p.index_select(dim=idx, index=tidxr)
                 if m == 1:
                     new_data = new_data.squeeze(idx)
                 p.data = new_data
