@@ -7,6 +7,7 @@
 from .initializers import initialize_q_batch, initialize_q_batch_nonneg
 from .numpy_converter import module_to_array, set_params_with_array
 from .optimize import gen_batch_initial_conditions, optimize_acqf, optimize_acqf_cyclic
+from .stopping import ExpMAStoppingCriterion
 
 
 __all__ = [
@@ -17,4 +18,5 @@ __all__ = [
     "optimize_acqf_cyclic",
     "module_to_array",
     "set_params_with_array",
+    "ExpMAStoppingCriterion",
 ]
