@@ -17,12 +17,13 @@ from torch import Tensor
 
 from ..acquisition.acquisition import AcquisitionFunction, OneShotAcquisitionFunction
 from ..acquisition.knowledge_gradient import qKnowledgeGradient
-from ..gen import gen_candidates_scipy
+from ..generation.gen import gen_candidates_scipy
+from ..logging import logger
 from .initializers import (
     gen_batch_initial_conditions,
     gen_one_shot_kg_initial_conditions,
 )
-from .utils import ConvergenceCriterion
+from .stopping import ExpMAStoppingCriterion
 
 
 def optimize_acqf(
@@ -105,7 +106,7 @@ def optimize_acqf(
         candidate_list, acq_value_list = [], []
         candidates = torch.tensor([])
         base_X_pending = acq_function.X_pending
-        for _ in range(q):
+        for i in range(q):
             candidate, acq_value = optimize_acqf(
                 acq_function=acq_function,
                 bounds=bounds,
@@ -129,6 +130,7 @@ def optimize_acqf(
                 if base_X_pending is not None
                 else candidates
             )
+            logger.info(f"Generated sequential candidate {i+1} of {q}")
         # Reset acq_func to previous X_pending state
         acq_function.set_X_pending(base_X_pending)
         return candidates, torch.stack(acq_value_list)
@@ -154,8 +156,8 @@ def optimize_acqf(
     batch_limit: int = options.get("batch_limit", num_restarts)
     batch_candidates_list: List[Tensor] = []
     batch_acq_values_list: List[Tensor] = []
-    start_idx = 0
-    while start_idx < num_restarts:
+    start_idcs = list(range(0, num_restarts, batch_limit))
+    for start_idx in start_idcs:
         end_idx = min(start_idx + batch_limit, num_restarts)
         # optimize using random restart optimization
         batch_candidates_curr, batch_acq_values_curr = gen_candidates_scipy(
@@ -174,7 +176,7 @@ def optimize_acqf(
         )
         batch_candidates_list.append(batch_candidates_curr)
         batch_acq_values_list.append(batch_acq_values_curr)
-        start_idx += batch_limit
+        logger.info(f"Generated candidate batch {start_idx+1} of {len(start_idcs)}.")
     batch_candidates = torch.cat(batch_candidates_list)
     batch_acq_values = torch.cat(batch_acq_values_list)
 
@@ -230,8 +232,7 @@ def optimize_acqf_cyclic(
         batch_initial_conditions: A tensor to specify the initial conditions.
             If no initial conditions are provided, the default initialization will
             be used.
-        cyclic_options: Options for convergence criterion for outer cyclic
-            optimization.
+        cyclic_options: Options for stopping criterion for outer cyclic optimization.
         Returns:
             A two-element tuple containing
 
@@ -269,11 +270,11 @@ def optimize_acqf_cyclic(
     )
     if q > 1:
         cyclic_options = cyclic_options or {}
-        convergence_criterion = ConvergenceCriterion(**cyclic_options)
-        converged = convergence_criterion.evaluate(fvals=acq_vals)
+        stopping_criterion = ExpMAStoppingCriterion(**cyclic_options)
+        stop = stopping_criterion.evaluate(fvals=acq_vals)
         base_X_pending = acq_function.X_pending
         idxr = torch.ones(q, dtype=torch.bool, device=bounds.device)
-        while not converged:
+        while not stop:
             for i in range(q):
                 # optimize only candidate i
                 idxr[i] = 0
@@ -300,6 +301,6 @@ def optimize_acqf_cyclic(
                 candidates[i] = candidate_i
                 acq_vals[i] = acq_val_i
                 idxr[i] = 1
-            converged = convergence_criterion.evaluate(fvals=acq_vals)
+            stop = stopping_criterion.evaluate(fvals=acq_vals)
         acq_function.set_X_pending(base_X_pending)
     return candidates, acq_vals
