@@ -7,6 +7,7 @@
 from .constraints import get_outcome_constraint_transforms
 from .objective import apply_constraints, get_objective_weights_transform
 from .sampling import (
+    batched_multinomial,
     construct_base_samples,
     construct_base_samples_from_posterior,
     draw_sobol_normal_samples,
@@ -18,6 +19,7 @@ from .transforms import squeeze_last_dim, standardize, t_batch_mode_transform
 
 __all__ = [
     "apply_constraints",
+    "batched_multinomial",
     "construct_base_samples",
     "construct_base_samples_from_posterior",
     "draw_sobol_normal_samples",
