@@ -13,12 +13,15 @@ from typing import List, Optional, Tuple
 from unittest import TestCase
 
 import torch
+from botorch.posteriors.gpytorch import GPyTorchPosterior
+from gpytorch.distributions import MultitaskMultivariateNormal, MultivariateNormal
+from gpytorch.lazy import AddedDiagLazyTensor, DiagLazyTensor
 from torch import Tensor
 
 from .. import settings
 from ..models.model import Model
 from ..posteriors import Posterior
-from ..test_functions.synthetic import SyntheticTestFunction
+from ..test_functions.base import BaseTestProblem
 
 
 EMPTY_SIZE = torch.Size()
@@ -40,9 +43,9 @@ class BotorchTestCase(TestCase):
         warnings.simplefilter("always", append=True)
 
 
-class SyntheticTestFunctionBaseTestCase:
+class BaseTestProblemBaseTestCase:
 
-    functions: List[SyntheticTestFunction]
+    functions: List[BaseTestProblem]
 
     def test_forward(self):
         for dtype in (torch.float, torch.double):
@@ -50,13 +53,18 @@ class SyntheticTestFunctionBaseTestCase:
                 for f in self.functions:
                     f.to(device=self.device, dtype=dtype)
                     X = torch.rand(*batch_shape, f.dim, device=self.device, dtype=dtype)
-                    X = f.bounds[0, :] + X * (f.bounds[1, :] - f.bounds[0, :])
+                    X = f.bounds[0] + X * (f.bounds[1] - f.bounds[0])
                     res = f(X)
                     f(X, noise=False)
                     self.assertEqual(res.dtype, dtype)
                     self.assertEqual(res.device.type, self.device.type)
-                    self.assertEqual(res.shape, batch_shape)
+                    tail_shape = torch.Size(
+                        [f.num_objectives] if f.num_objectives > 1 else []
+                    )
+                    self.assertEqual(res.shape, batch_shape + tail_shape)
 
+
+class SyntheticTestFunctionBaseTestCase(BaseTestProblemBaseTestCase):
     def test_optimal_value(self):
         for dtype in (torch.float, torch.double):
             for f in self.functions:
@@ -204,3 +212,49 @@ def _get_random_data(
     train_y = torch.sin(train_x * (2 * math.pi))
     train_y = train_y + 0.2 * torch.randn(n, num_outputs, **tkwargs).repeat(rep_shape)
     return train_x, train_y
+
+
+def _get_test_posterior(
+    batch_shape: torch.Size,
+    q: int = 1,
+    m: int = 1,
+    interleaved: bool = True,
+    lazy: bool = False,
+    independent: bool = False,
+    **tkwargs
+) -> GPyTorchPosterior:
+    r"""Generate a Posterior for testing purposes.
+
+    Args:
+        batch_shape: The batch shape of the data.
+        q: The number of candidates
+        m: The number of outputs.
+        interleaved: A boolean indicating the format of the
+            MultitaskMultivariateNormal
+        lazy: A boolean indicating if the posterior should be lazy
+        indepedent: A boolean indicating whether the outputs are independent
+        tkwargs: `device` and `dtype` tensor constructor kwargs.
+
+
+    """
+    if independent:
+        mvns = []
+        for _ in range(m):
+            mean = torch.rand(*batch_shape, q, **tkwargs)
+            a = torch.rand(*batch_shape, q, q, **tkwargs)
+            covar = a @ a.transpose(-1, -2)
+            flat_diag = torch.rand(*batch_shape, q, **tkwargs)
+            covar = covar + torch.diag_embed(flat_diag)
+            mvns.append(MultivariateNormal(mean, covar))
+        mtmvn = MultitaskMultivariateNormal.from_independent_mvns(mvns)
+    else:
+        mean = torch.rand(*batch_shape, q, m, **tkwargs)
+        a = torch.rand(*batch_shape, q * m, q * m, **tkwargs)
+        covar = a @ a.transpose(-1, -2)
+        flat_diag = torch.rand(*batch_shape, q * m, **tkwargs)
+        if lazy:
+            covar = AddedDiagLazyTensor(covar, DiagLazyTensor(flat_diag))
+        else:
+            covar = covar + torch.diag_embed(flat_diag)
+        mtmvn = MultitaskMultivariateNormal(mean, covar, interleaved=interleaved)
+    return GPyTorchPosterior(mtmvn)
