@@ -1,4 +1,4 @@
-#! /usr/bin/env python3
+#!/usr/bin/env python3
 # Copyright (c) Facebook, Inc. and its affiliates.
 #
 # This source code is licensed under the MIT license found in the
@@ -61,11 +61,7 @@ class TestQExpectedImprovement(BotorchTestCase):
             res = acqf(X)
             self.assertEqual(res.item(), 1.0)
 
-            # test size verification of best_f
-            with self.assertRaises(ValueError):
-                qExpectedImprovement(
-                    model=mm, best_f=torch.zeros(2, device=self.device, dtype=dtype)
-                )
+            # TODO: Test batched best_f, batched model, batched evaluation
 
             # basic test, no resample
             sampler = IIDNormalSampler(num_samples=2, seed=12345)
